@@ -34,6 +34,7 @@ class Sections:
     Cache = 'cache'
     Archiver = 'archiver'
     Coordinator = 'coordinator'
+    Rest = 'rest'
 
 
 class HTTP_STATUS_CODE:
@@ -167,6 +168,11 @@ class RequestGroupType(IDDSEnum):
     Other = 99
 
 
+class RequestAdditionalDataStorage(IDDSEnum):
+    Default = 0
+    OnDisk = 1
+
+
 class RequestStatus(IDDSEnum):
     New = 0
     Ready = 1
@@ -357,6 +363,7 @@ class ContentStatus(IDDSEnum):
     Activated = 11
     SubAvailable = 12
     FinalSubAvailable = 13
+    PreProcessing = 14
 
 
 class ContentLocking(IDDSEnum):
@@ -422,6 +429,7 @@ class ProcessingStatus(IDDSEnum):
     ToTrigger = 28
     Triggering = 29
     Synchronizing = 30
+    Prepared = 31
 
 
 Terminated_processing_status = [ProcessingStatus.Finished,
