@@ -6,7 +6,7 @@
 # http://www.apache.org/licenses/LICENSE-2.0OA
 #
 # Authors:
-# - Wen Guan, <wen.guan@cern.ch>, 2019 - 2024
+# - Wen Guan, <wen.guan@cern.ch>, 2019 - 2025
 # - Lino Oscar Gerlach, <lino.oscar.gerlach@cern.ch>, 2024
 
 import base64
@@ -29,10 +29,10 @@ import sys
 import tarfile
 import threading
 import time
-# import traceback
 
 from enum import Enum
 from functools import wraps
+from logging.handlers import RotatingFileHandler
 from itertools import groupby
 from operator import itemgetter
 from packaging import version as packaging_version
@@ -139,7 +139,7 @@ def get_logger(name, filename=None, loglevel=None):
 
     formatter = logging.Formatter('%(asctime)s\t%(threadName)s\t%(name)s\t%(levelname)s\t%(message)s')
 
-    handler = logging.FileHandler(filename)
+    handler = RotatingFileHandler(filename, maxBytes=2 * 1024 * 1024 * 1024, backupCount=3)
     handler.setFormatter(formatter)
     logger = logging.getLogger(name)
     logger.setLevel(loglevel)
